@@ -106,11 +106,9 @@ addMultiPlotSmoother <- function(i, x, complete, cbPalette, f, span,
         as.numeric(smooth.data$date), span = span)
       x.date <- as.Date(smooth.data$x, origin = "1970-01-01")
       lines(x.date, smooth.data$fitted, col = cbPalette[i])
-      title(sub = paste("loess span =", round(span, 2)), cex.sub = 0.9)
     } else {
       lines(stats::lowess(smooth.data$date, smooth.data[, statistic], f = f),
         col = cbPalette[i])
-      title(sub = paste("lowess f =", round(f, 2)), cex.sub = 0.9)
     }
   } else if (any(dat$partial)) {
     tmp <- rbind(wk1.backdate, complete)
@@ -122,11 +120,9 @@ addMultiPlotSmoother <- function(i, x, complete, cbPalette, f, span,
         as.numeric(tmp$date), span = span)
       x.date <- as.Date(smooth.data$x, origin = "1970-01-01")
       lines(x.date, smooth.data$fitted, col = cbPalette[i])
-      title(sub = paste("loess span =", round(span, 2)), cex.sub = 0.9)
     } else {
       smooth.data <- stats::lowess(tmp$date, tmp[, statistic], f = f)
       lines(smooth.data$x, smooth.data$y, col = cbPalette[i])
-      title(sub = paste("lowess f =", round(f, 2)), cex.sub = 0.9)
     }
   } else {
     if (nrow(dat) > 7) {
@@ -134,11 +130,9 @@ addMultiPlotSmoother <- function(i, x, complete, cbPalette, f, span,
         span = span)
       x.date <- as.Date(smooth.data$x, origin = "1970-01-01")
       lines(x.date, smooth.data$fitted, col = cbPalette[i])
-      title(sub = paste("loess span =", round(span, 2)), cex.sub = 0.9)
     } else {
       lines(stats::lowess(dat[dat$package == x$packages[i], vars], f = f),
         col = cbPalette[i])
-      title(sub = paste("lowess f =", round(f, 2)), cex.sub = 0.9)
     }
   }
 }
@@ -151,16 +145,14 @@ addRPlotSmoother <- function(x, complete, f, span, pltfrm, pltfrm.col,
   if (any(dat$in.progress)) {
     invisible(lapply(seq_along(complete), function(i) {
       tmp <- complete[[i]]
-      if (nrow(dat) > 7) {
+      if (nrow(tmp) > 7) {
         smooth.data <- stats::loess(tmp[, statistic] ~ as.numeric(tmp$date), 
           span = span)
         x.date <- as.Date(smooth.data$x, origin = "1970-01-01")
         lines(x.date, smooth.data$fitted, lwd = 1.5, col = pltfrm.col[i])
-        title(sub = paste("loess span =", round(span, 2)), cex.sub = 0.9)
       } else {
         smooth.data <- stats::lowess(tmp$date, tmp[, statistic], f = f)
         lines(smooth.data, lwd = 1.5, col = pltfrm.col[i])
-        title(sub = paste("lowess f =", round(f, 2)), cex.sub = 0.9)
       }
     }))
   } else if (any(dat$partial)) {
@@ -171,11 +163,9 @@ addRPlotSmoother <- function(x, complete, f, span, pltfrm, pltfrm.col,
           span = span)
         x.date <- as.Date(smooth.data$x, origin = "1970-01-01")
         lines(x.date, smooth.data$fitted, lwd = 1.5, col =  pltfrm.col[i])
-        title(sub = paste("loess span =", round(span, 2)), cex.sub = 0.9)
       } else {
         smooth.data <- stats::lowess(tmp$date, tmp[, statistic], f = f)
         lines(smooth.data$x, smooth.data$fitted, lwd = 1.5, col = pltfrm.col[i])
-        title(sub = paste("lowess f =", round(f, 2)), cex.sub = 0.9)
       }
     }))
   } else {
@@ -186,14 +176,18 @@ addRPlotSmoother <- function(x, complete, f, span, pltfrm, pltfrm.col,
           as.numeric(tmp$date), span = span)
         x.date <- as.Date(smooth.data$x, origin = "1970-01-01")
         lines(x.date, smooth.data$fitted, lwd = 1.5, col = pltfrm.col[i])
-        title(sub = paste("loess span =", round(span, 2)), cex.sub = 0.9)
       } else {
         smooth.data <- stats::lowess(tmp$date, tmp[, statistic], f = f)
         lines(smooth.data, lwd = 1.5, col = pltfrm.col[i])
-        title(sub = paste("lowess f =", round(f, 2)), cex.sub = 0.9)
       }
     }))
   }
+  
+  if (nrow(dat) > 7) {
+    title(sub = paste("loess span =", round(span, 2)), cex.sub = 0.9)
+  } else {
+    title(sub = paste("lowess f =", round(f, 2)), cex.sub = 0.9)
+  }
 }
 
 addRTotPlotSmoother <- function(dat, complete, f, span, statistic,
